//
//  ViewController.swift
//  ColorMixer
//
//  Created by Holger Hinzberg on 06.01.16.
//  Copyright © 2016 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController,
    UIPickerViewDataSource, UIPickerViewDelegate
{
    var formatter:NSNumberFormatter?
    
    @IBOutlet var hexStringValueTextField: UITextField!
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        self.formatter = NSNumberFormatter();
        // Die aktuellen Landeseinstellungen zuweisen
        self.formatter?.locale = NSLocale.currentLocale()
        // Einen Style zur Formatierung festlegen
        self.formatter?.numberStyle
            = NSNumberFormatterStyle.DecimalStyle
        // Zwei Nachkommastellen sollen es sein
        self.formatter?.minimumFractionDigits = 2
        self.formatter?.maximumFractionDigits = 2
        
        self.view.backgroundColor = UIColor.blackColor()
        self.hexStringValueTextField.text = "#000000"
     }
    
    func pickerView(pickerView: UIPickerView,
       titleForRow row: Int,
       forComponent component: Int) -> String?
    {
        let value = 0.1 * Double(row)
        let number = NSNumber(double: value)
        let title = self.formatter!.stringFromNumber(number)
        return title
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func numberOfComponentsInPickerView(pickerView: UIPickerView) -> Int
    {
        // Drei Spalten für die Farbanteile
        // Rot, Grün, Blau
        return 3
    }
    
    func pickerView(pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int
    {
        // Elf Unterteilungen pro Farbanteil
        return 11
    }
    
    func pickerView(pickerView: UIPickerView,
        didSelectRow row: Int,
        inComponent component: Int)
    {
        // Die Einstellungen der Rows (Walzen/Spalten) holen
        let row0Value
          = pickerView.selectedRowInComponent(0)
        let row1Value
          = pickerView.selectedRowInComponent(1)
        let row2Value
          = pickerView.selectedRowInComponent(2)
        
        // Mit dem Faktor der Farbanteile multiplizieren
        let redValue = Float(row0Value) * 0.1
        let greenValue = Float(row1Value) * 0.1
        let blueValue = Float(row2Value) * 0.1
        
        // Eine Farbe aus den einzelnen
        // Farbanteilen zusammenstellen
        let color = UIColor(colorLiteralRed: redValue,
            green: greenValue, blue: blueValue, alpha: 1)
        
        // Die Hintergrundfarbe für den View setzen
        self.view.backgroundColor = color
  
        // Die Hintergrundfarbe in die 
        // Hexadezimale Schreibweise umwandeln
        let colorString = self.createHexStringFromUIColor(color)
        print(colorString)
        
        self.hexStringValueTextField.text = colorString
    }
    
    func createHexStringFromUIColor(color:UIColor) -> String
    {
        var redValue:CGFloat = 0.0
        var greenValue:CGFloat = 0.0
        var blueValue:CGFloat = 0.0
        var alphaValue:CGFloat = 0.0
        
        // Die Farbanteile aus dem UIColor-Objekt auslesen
        color.getRed(&redValue, green: &greenValue, blue: &blueValue, alpha: &alphaValue)
        
        redValue = redValue * 255.0
        greenValue = greenValue * 255.0
        blueValue = blueValue * 255.0
        
        // Jeden Farbanteil in einen hexadezimalen
        // Wert umwandeln
        let redString = String(format: "%02X", Int(redValue))
        let greenString = String(format: "%02X", Int(greenValue))
        let blueString = String(format: "%02X", Int(blueValue))
    
        // Zeichenkette zusammenfügen und in
        // Großbuchstaben umwandeln
        var colorString = "#" + redString
            + greenString + blueString
        colorString = colorString.uppercaseString
        
        return colorString
    }
  
}





